pywurfl.wurflprocessor

Package pywurfl :: Module wurflprocessor |
[hide private]
[frames] | no frames]

# Module wurflprocessor

source code

WURFL processing utility.

Author: Armand Lynch <lyncha@users.sourceforge.net>

Copyright: Copyright 2004-2010, Armand Lynch

License: LGPL

Classes | [hide private]
| DeferredDeviceError Deferred Device Error Exception
| DeviceHandler Base class for DeviceHandler objects
| WurflProcessor WURFL Processing Class

Functions | [hide private]
main(processor_class, device_handler_class, option_parser) Main utility function | source code

Variables | [hide private]
| __doc__ = ``...``
| __contributors__ = ``'``Pau Aliagas <pau@newtral.org>``'``
| __url__ = ``'``http://celljam.net/``'``
| usage = ``'``usage: %prog [options] WURFL_XML_FILE``'``
| op = `OptionParser(usage= usage)`

Function Details | [hide private]

### main(processor_class, device_handler_class, option_parser) | source code
Main utility function Function to help instantiate a WurflProcessor class or subclass with additional command line options. Parameters: `processor_class` (WurflProcessor) - The WurflProcessor class or a subclass. `device_handler_class` (DeviceHandler) - A reference to a subclass of DeviceHandler. `option_parser` (OptionParser.OptionParser) - An instance of OptionParser. The dictionary from this object will be passed to processor_class in the keyword 'option'.

Variables Details | [hide private]

  ### __doc__ Value:
      """
      WURFL processing utility.
      """